PAWpySeed: real_proj Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
real_proj Struct Reference

`#include <utils.h>`

## Public Attributes
int | l
int | m
int | func_num
double * | paths
double complex * | values

## Member Data Documentation

int real_proj::func_num

int real_proj::l

int real_proj::m

double* real_proj::paths

double complex* real_proj::values

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h